ShouldImpl

Struct ShouldImpl 

pub struct ShouldImpl<L>
where L: Debug,
{ pub left: Option<L>, /* private fields */ }
The inner should implementation, not intended to be used by the final user.

Fields

left: Option<L>

The left part of the assertion.

Implementations

Source

impl<L> ShouldImpl<L>
where L: Debug,

pub fn map_left<T: Debug, F>(self, f: F) -> ShouldImpl<T>
where F: FnOnce(L) -> Option<T>,

Creates a new ShouldImpl by applicating the passed closure to the left element.

pub fn truthness(&self) -> bool

Returns wether the assertion should be true or not.

pub fn left_dbg(&self) -> &str

Returns a debug reptresentation of the left element.

pub fn stringified(&self) -> Option<String>

Returns a stringified representation of the left element.

pub fn add_message(&mut self, message: String)

Adds a new explanation message to the assertion. Must be used through the ConsumingAssert::because or the ChainableAssert::because method.